xsdata.formats.plantuml package
===============================

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.formats.plantuml.generator

Module contents
---------------

.. automodule:: xsdata.formats.plantuml
   :members:
   :undoc-members:
   :show-inheritance:
